auto_stop_handler library

Automatic location tracking lifecycle management.

This library provides AutoStopHandler, a widget binding observer that automatically stops background location tracking when the app lifecycle changes. Use this to conserve battery by stopping location updates when the user is not actively using the app.

Classes

AutoStopHandler
Handles automatic stopping of location tracking when the app lifecycle changes.