AndroidNotificationSettings constructor

const AndroidNotificationSettings({
  1. String notificationChannelName = 'Location tracking',
  2. String notificationTitle = 'Start Location Tracking',
  3. String notificationMsg = 'Track location in background',
  4. String notificationBigMsg = 'Background location is on to keep the app up-tp-date with your location. This is required for main features to work properly when the app is not running.',
  5. String notificationIcon = '',
  6. Color notificationIconColor = Colors.grey,
  7. VoidCallback? notificationTapCallback,
})

Creates an AndroidNotificationSettings instance.

All parameters are optional and have sensible defaults.

Implementation

const AndroidNotificationSettings(
    {this.notificationChannelName = 'Location tracking',
    this.notificationTitle = 'Start Location Tracking',
    this.notificationMsg = 'Track location in background',
    this.notificationBigMsg =
        'Background location is on to keep the app up-tp-date with your location. This is required for main features to work properly when the app is not running.',
    this.notificationIcon = '',
    this.notificationIconColor = Colors.grey,
    this.notificationTapCallback});