notificationBigMsg property

String notificationBigMsg
final

The expanded message shown when the notification is expanded. Default: 'Background location is on to keep the app up-to-date with your location...'

Implementation

final String notificationBigMsg;