notificationIconColor property
The color of the notification icon in the notification drawer. Default: Colors.grey
Implementation
final Color notificationIconColor;
The color of the notification icon in the notification drawer. Default: Colors.grey
final Color notificationIconColor;