showsBackgroundLocationIndicator property

bool showsBackgroundLocationIndicator
final

Whether to show the blue background location indicator in the status bar.

When true, a blue bar or pill appears in the status bar to indicate that the app is using location services in the background. Default: false

Implementation

final bool showsBackgroundLocationIndicator;