unRegisterLocationUpdate static method
Unregisters the location update callback and stops background tracking.
After calling this method, no more location updates will be received. The location service will be stopped on both Android and iOS.
Throws a PlatformException if unregistration fails.
Implementation
static Future<void> unRegisterLocationUpdate() async {
await _channel.invokeMethod(Keys.METHOD_PLUGIN_UN_REGISTER_LOCATION_UPDATE);
}