keys library
Platform channel communication constants for the location_tracking plugin.
This library provides the Keys class containing all constant strings used for communication between Dart and native platform code (Android/iOS).
Classes
- Keys
- Constants used for platform channel communication and data mapping.