AndroidNotificationSettings constructor
const
AndroidNotificationSettings({
- String notificationChannelName = 'Location tracking',
- String notificationTitle = 'Start Location Tracking',
- String notificationMsg = 'Track location in background',
- String notificationBigMsg = 'Background location is on to keep the app up-tp-date with your location. This is required for main features to work properly when the app is not running.',
- String notificationIcon = '',
- Color notificationIconColor = Colors.grey,
- VoidCallback? notificationTapCallback,
Creates an AndroidNotificationSettings instance.
All parameters are optional and have sensible defaults.
Implementation
const AndroidNotificationSettings(
{this.notificationChannelName = 'Location tracking',
this.notificationTitle = 'Start Location Tracking',
this.notificationMsg = 'Track location in background',
this.notificationBigMsg =
'Background location is on to keep the app up-tp-date with your location. This is required for main features to work properly when the app is not running.',
this.notificationIcon = '',
this.notificationIconColor = Colors.grey,
this.notificationTapCallback});