stopWithTerminate property
Whether to stop location tracking when the app is terminated.
When true, location tracking stops if the user force-closes the app. When false, location tracking continues even after app termination. Default: false
Implementation
final bool stopWithTerminate;